

#ifndef _Oz_Base_Manager_ICE_
#define _Oz_Base_Manager_ICE_

#include <Ice/Identity.ice>
#include <Base/Session.ice>

module Oz
{
	module Base
	{
		class ServerManager;
		exception AuthDeniedException
		{
			Ice::Identity objectId;
			string methodName;
			string userName;
		};
		
		struct RollInfo
		{
			Ice::Identity id;
			string name;
		};
		
		interface ManagerAdmin
		{
			nonmutating ServerManager* getServerManager();
			idempotent void setServerManager(ServerManager* managerServerPx);
			
			nonmutating Ice::Identity getId();
			
			nonmutating Ice::Identity getSessionId();
			
			nonmutating Session* getSession();
			
			nonmutating Ice::Identity getObjectId();
			
			idempotent void destroy();
			
			/**
			 * Recuperar el usuario asociado al manager
			 */
			nonmutating Oz::Domains::User* getUser();

			
			/**
			 * Controlar los permisos
			 */
			
			idempotent RollInfo createRoll(string name)
				throws Oz::Base::AuthDeniedException;
			
			idempotent void removeRoll(Ice::Identity objectId,string roll)
				throws Oz::Base::AuthDeniedException;
			
			idempotent void addEntityToRoll(Ice::Identity entityId,string roll)
				throws Oz::Base::AuthDeniedException;
			
			idempotent void delEntityFromRoll(Ice::Identity entityId,string roll)
				throws Oz::Base::AuthDeniedException;
		};
		
		class Manager implements ManagerAdmin
		{
			ServerManager* serverManagerPx;
			Ice::Identity id;
			Ice::Identity sessionId;
			Oz::Base::Session* sessionPx;
			Oz::Base::OnRez* objectPx;
		};
		
		dictionary<Ice::Identity,Manager*>ManagerMap;
	};
};

#endif