
/***************************************************************************/
/*Copyright (C)  On-Rez                                                   **/
/*www.on-rez.com                                                          **/
/*                                                                        **/
/*This code is licensed to you under the terms of GPL license             **/
/*a copy ot it is available with the sources in the file LICENSE.         **/
/*you can view online at http://www.gnu.org/licenses/gpl.txt              **/
/***************************************************************************/

#ifndef _Oz_Files_FileSystem_ICE_
#define _Oz_Files_FileSystem_ICE_

#include <Base/OnRez.ice>
#include <Files/Node.ice>
#include <Files/Link.ice>

module Oz
{
	module Files
	{	
		interface FileSystemWriter
		{
			idempotent void 
			setName(
				string name);
			
			idempotent void
			setRootNode(
				Node* rootNode);
				
			/**
			 * Permite crear un nuevo nodo en el sistema de ficheros
			 *
			 * @param type, el tipo de nodo que queremos crear 
			 * ("Directory","File","Document","Image")
			 * @param name, el nombre que se asignara al nuevo nodo
			 *
			 * @param path, ruta en la que se crea el nuevo nodo
			 *
			 * @returns Node*, proxy al nuevo nodo 
			 */

			idempotent Node* 
			createNode(
				string type,
				string name,
				string path);

			idempotent Link*
			createLink(
				string name,
				string sourcePath,
				string targetPath);
			
			idempotent void 
			deleteNode(
				Node* nodo);

			idempotent void
			copyNode(
				Node* sourceNode,
				string targetPath,
				FileSystem* targeFileSystem);

			idempotent void
			moveNode(
				Node* sourceNode,
				string targetPath,
				FileSystem* targeFileSystem);
		};
		
		interface FileSystemReader
		{
			/**
			 * Nombre asignado al sistema de ficheros
			 */
			nonmutating string 
			getName();
			
			/**
			 * Permite recuperar un proxy a un nodo dado su 
			 * path.
			 */
			nonmutating Node* 
			getNode(
				string path);
		};
		
		/**
		 * Esta clase represneta un sistema de ficheros
		 * 
		 */
		class FileSystem 
			extends 
				Oz::Base::OnRez 
			implements 
				FileSystemWriter,
				FileSystemReader
		{
			/**
			 * Nombre del sistema de ficheros.
			 */
			
			string name;
			
			/*
			 * Proxy al directorio raiz del sistema
			 * de ficheros.
			 */
			Node* rootNode;
		};
	};
};
#endif

